<?php
	/*
	+--------------------------------------------------------------------------
	|   Project-Alumni v1.0.0
	|   =============================================
	|   by Stephen Eskin and Jason Leveille
	|	(c) 2003 - 2006 Project-Alumni.
	|   http://www.project-alumni.org
	|   =============================================
	|   Web: http://www.project-alumni.org
	|   Time: Mon, 19 Jul 2006 02:11:59 EST
	+---------------------------------------------------------------------------
	|
	|   > Misc Functions
	|   > Module written by Stephen Eskin
	|   > Date started: 22th June 2006
	|
	+--------------------------------------------------------------------------
	*/

	/************************************************
	 * Name: Convert DateTime (datetime_convert)	*
	 * Desc: Converts mySQL DateTime to php.		*
	 * Pre:  $datetime is a valid mySQL DateTime,	*
	 *		 $type1 and $type2 are valid ints		*
	 * Post: Returns formatted DateTime.			*
	 ************************************************/
	function datetime_convert($datetime, $type1, $type2, $output){
		$date = substr($datetime,0,10);
		$time = substr($datetime,11,8);
		
		$newdate = date_convert($date,$type1);
		$newtime = time_convert($time,$type2);
		if($output == 1){
			$newdatetime = $newdate. "<br />". $newtime;
		}
		else{
			$newdatetime = $newdate. " ". $newtime;
		}
	
		return $newdatetime;
	}
	
	/************************************************
	 * Name: Convert Date (date_convert)			*
	 * Desc: Converts mySQL Date to php.			*
	 * Pre:  $date is a valid mySQL Date,			*
	 *		 $type is a valid int					*
	 * Post: Returns formatted Date.				*
	 ************************************************/
	function date_convert($date,$type){
	  $date_year=substr($date,0,4);
	  $date_month=substr($date,5,2);
	  $date_day=substr($date,8,2);
	  if($type == 1):
		// Returns the year Ex: 2003
		$date=date("Y", mktime(0,0,0,$date_month,$date_day,$date_year));
	  elseif($type == 2):
		// Returns the month Ex: January
		$date=date("F", mktime(0,0,0,$date_month,$date_day,$date_year));
	  elseif($type == 3):
		// Returns the short form of month Ex: Jan
		$date=date("M", mktime(0,0,0,$date_month,$date_day,$date_year));
	  elseif($type == 4):
		// Returns numerical representation of month with leading zero Ex: Jan = 01, Feb = 02
		$date=date("m", mktime(0,0,0,$date_month,$date_day,$date_year));
	  elseif($type == 5):
		// Returns numerical representation of month without leading zero Ex: Jan = 1, Feb = 2
		$date=date("n", mktime(0,0,0,$date_month,$date_day,$date_year));
	  elseif($type == 6):
		// Returns the day of the week Ex: Monday
		$date=date("l", mktime(0,0,0,$date_month,$date_day,$date_year));
	  elseif($type == 7):
		// Returns the day of the week in short form Ex: Mon, Tue
		$date=date("D", mktime(0,0,0,$date_month,$date_day,$date_year));
	  elseif($type == 8):
		// Returns a combo ExL Wed,Nov 12th,2003
		$date=date("D, M jS, Y", mktime(0,0,0,$date_month,$date_day,$date_year));
	  elseif($type == 9):
		// Returns a combo Ex: November 12th,2003
		$date=date("F jS, Y", mktime(0,0,0,$date_month,$date_day,$date_year));
	  elseif($type == 10):
		// Returns the day of the month without the leading zeros Ex: 1, 2, 13
		$date=date("j", mktime(0,0,0,$date_month,$date_day,$date_year));
	  elseif($type == 11):
		// Returns date in normal format Ex: 11/17/2004
		$date = $date_month. "/". $date_day. "/". $date_year;
	  elseif($type == 12):
		// Returns date in normal format with no year Ex: 11/17
		$date = $date_month. "/". $date_day;
	  endif;
	  return $date;
	};
	
	/************************************************
	 * Name: Convert Time (time_convert)			*
	 * Desc: Converts mySQL Time to php.			*
	 * Pre:  $time is a valid mySQL Time,			*
	 *		 $type is a valid int					*
	 * Post: Returns formatted Time.				*
	 ************************************************/
	function time_convert($time,$type){
	  $time_hour=substr($time,0,2);
	  $time_minute=substr($time,3,2);
	  $time_seconds=substr($time,6,2);
	  if($type == 1):
		// 12 Hour Format with uppercase AM-PM
		$time=date("g:i A", mktime($time_hour,$time_minute,$time_seconds));
	  elseif($type == 2):
		// 12 Hour Format with lowercase am-pm
		$time=date("g:i a", mktime($time_hour,$time_minute,$time_seconds)); 
	  elseif($type == 3):
		// 24 Hour Format
		$time=date("H:i", mktime($time_hour,$time_minute,$time_seconds)); 
	  elseif($type == 4):
		// Swatch Internet time 000 through 999
		$time=date("B", mktime($time_hour,$time_minute,$time_seconds)); 
	  elseif($type == 5):
		// 9:30:23 PM
		$time=date("g:i:s A", mktime($time_hour,$time_minute,$time_seconds));
	  elseif($type == 6):
		// 9:30 PM with timezone, EX: EST, MDT
		$time=date("g:i A T", mktime($time_hour,$time_minute,$time_seconds));
	  elseif($type == 7):
		// Different to Greenwich(GMT) time in hours
		$time=date("O", mktime($time_hour,$time_minute,$time_seconds)); 
	  elseif($type == 8):
		// 12 Hour Format with lowercase am-pm with no space
		$time=date("g:ia", mktime($time_hour,$time_minute,$time_seconds)); 
	  endif;
	  return $time;
	};
	
	/************************************************
	 * Name: Make Cal List (make_calendar_pulldown)	*
	 * Desc: Creates a drop down list of months, 	*
	 *		 days and years.						*
	 * Pre:  $eventYear, $eventMonth, $eventDay, 	*
	 *		 and $hideDate are NULL/valid Strings.	*
	 * Post: Displays a dropdown list.				*
	 ************************************************/
	function make_calendar_pulldown($eventYear,$eventMonth,$eventDay,$hideDate){
		$months = array(1 => 'January', 'February', 'March', 'April', 'May',
					'June', 'July', 'August', 'September', 'October',
					'November', 'December');
		if(!$eventYear) { $eventYear = date("Y"); }
		if(!$eventMonth) { $eventMonth = date("n"); }
		if(!$eventDay) { $eventDay = date("j"); }
		
		if($hideDate == "Yes")
			$disable = "disabled";
		else
			$disable = "";
		
		#Setting up the month loop for the pulldown menu
		echo "<select name=\"dropMonth\" $disable>";
		foreach ($months as $key => $value){
			echo "<option value = \"$key\"";
				if($key == $eventMonth){
					echo 'selected = "selected"';
				}
				echo ">$value</option>\n";
		}
		echo '</select>  ';
		
		
		echo "<select name = \"dropDay\" $disable>";
		for ($day = 1; $day <=31; $day++){
			echo "<option value = \"$day\"";
				if($day == $eventDay){
					echo 'selected = "selected"';
				}
				echo ">$day</option>\n";
		}
				
		echo '</select>  ';
		echo "<select name=\"dropYear\" $disable>";
			echo "<option value=\"" . ((int) $eventYear - 2) . "\">" . ((int) $eventYear - 2) . "</option>";
			echo "<option value=\"" . ((int) $eventYear - 1) . "\">" . ((int) $eventYear - 1) . "</option>";
			echo "<option value=\"" . ((int) $eventYear) . "\" selected>" . ((int) $eventYear) . "</option>";
			echo "<option value=\"" . ((int) $eventYear + 1) . "\">" . ((int) $eventYear + 1) . "</option>";
			echo "<option value=\"" . ((int) $eventYear + 2) . "\">" . ((int) $eventYear + 2) . "</option>";
		echo "</select>";
	}
	
	/************************************************
	 * Name: Check Email Address (checkEmail)		*
	 * Desc: Validates a String as an email addr.	*
	 * Pre:  $email is a valid String				*
	 * Post: Returns TRUE if valid, FALSE if not.	*
	 ************************************************/
	function checkEmail($email)
	{
	   // Create the syntactical validation regular expression
	   $regexp = "^([_a-z0-9-]+)(\.[_a-z0-9-]+)*@([a-z0-9-]+)(\.[a-z0-9-]+)*(\.[a-z]{2,4})$";
	
	   // Presume that the email is invalid
	   $valid = FALSE;
	
	   // Validate the syntax
	   if (eregi($regexp, $email))
		  $valid = TRUE;

	   return $valid;
	}
	
	/************************************************
	 * Name: Random String (randomStr)				*
	 * Desc: Creates a random String of $length 	*
	 *		 length, used for activation codes.		*
	 * Pre:  $length is a valid int.				*
	 * Post: Returns a random String.				*
	 ************************************************/
	function randomStr($length){
		#Edit this string to change the characters that can be used to create the string
		$chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789";
			$len = strlen($chars);  
	
		$string = "";
		
		for($i = 0; $i < $length; $i++) {
			$pos = mt_rand(0, $len);            #Generate a random position in the $chars string
			$string .= substr($chars, $pos, 1);        #Add the character at that position to the end of $string
		}
	
		return $string;
	}
?>