<?php
	/*
	+--------------------------------------------------------------------------
	|   Project-Alumni v1.0.0
	|   =============================================
	|   by Stephen Eskin and Jason Leveille
	|	(c) 2003 - 2006 Project-Alumni.
	|   http://www.project-alumni.org
	|   =============================================
	|   Web: http://www.project-alumni.org
	|   Time: Mon, 19 Jul 2006 02:11:59 EST
	+---------------------------------------------------------------------------
	|
	|   > System Functions
	|   > Module written by Stephen Eskin
	|   > Date started: 19th June 2006
	|
	+--------------------------------------------------------------------------
	*/

	/************************************************
	 * Name: Site Startup Check (checkSiteStartup)  *
	 * Desc: Tests to make sure the site is up and  *
	 *		 running correctly.						*
	 * Pre:  NULL									*
	 * Post: Displays any errors or warnings on		*
	 *		 site startup.							*
	 ************************************************/
	function checkSiteStartup() {
		//Check for Config file
		$configFileStatus = validConfigFile();
		if($configFileStatus) { displaySiteError("Fatal",$configFileStatus,"die"); }
		
		//Connect\Check Database
		dbConnect();
	}

	/************************************************
	 * Name: Validate Config File (validConfigFile) *
	 * Desc: Tests to make sure the configuration   *
	 *		 file is valid and read/writeable.		*
	 * Pre:  NULL									*
	 * Post: Returns NULL if valid, or returns a	*
	 * 		 String with error details if not.		*
	 ************************************************/
	function validConfigFile() {
		global $dashConfigPath;
		
		//If the config file does not exist
		if (!file_exists($dashConfigPath)) {
			if($errorDetails) { $errorDetails .= "<br />"; }
			$errorDetails .= "* Configuration file does not exist! Try to replace it.";
		} 
		//If the config file is not readable
		if (!$handle = fopen($dashConfigPath, 'r+')) {
			if($errorDetails) { $errorDetails .= "<br />"; }
			$errorDetails .= "* Cannot open configuration file! Please adjust the permissions to allow this script to read the file. If in doubt, CHMOD via FTP to 0777.";
		}
		//If the config file is not writable
		if (!is_writable($dashConfigPath)) {
			if($errorDetails) { $errorDetails .= "<br />"; }
			$errorDetails .= "* Cannot write to configuration file! Please adjust the permissions to allow this script to write to the file. If in doubt, CHMOD via FTP to 0777.";
		}
		//Close the file
		fclose($handle);
		//Check if Config file is valid by size
		if(filesize($dashConfigPath) < 1500) {
			if($errorDetails) { $errorDetails .= "<br />"; }
			$errorDetails .= "* The configuration file seems to be corrupt or invalid.  Please try installing Project-Alumni again, or contact technical support.";
		}

		//If any errors exist
		if($errorDetails) {
			return $errorDetails; //Return the errors
		} else {
			//Set Time Zone
			if ( getConfigVal("alumniTimeZone") && !ini_get("safe_mode")) {
				putenv('"TZ=' . getConfigVal("alumniTimeZone",2) . '"');
			}//otherwise rely on the server to set the time
			return; //Return NULL
		}
	}

	/************************************************
	 * Name: Get Configuration Value (getConfigVal) *
	 * Desc: Returns the value of a configuration   *
	 *		 variable based on a variable name.		*
	 * Pre:  String $varName is not null			*
	 *		 String $returnNum is null/a valid int  *
	 * Post: Returns String $configLineData			*
	 ************************************************/
	function getConfigVal($varName,$returnNum=2) {
		//Path to configuration file
		global $dashConfigPath;
		$configPath = $dashConfigPath;
		$configLines = file($configPath); //Create array of lines of config file
		
		//Return UNKNOWN if no config file exists... yikes!
		if(!$configLines) { return "UNKNOWN"; }
		
		//For each line of array, store line to $configLine, index of $configLine_num
		foreach ($configLines as $configLine_num => $configLine) {
			//If the line is not php, a comment (#), and line is not blank ("")
			if((substr($configLine,0,5) != "<?php") && (substr($configLine,0,1) != "#") && (substr($configLine,0,1) != "")) {
				$configLineData = explode("=",$configLine); //Create array of [0]=varName, [1]=Var Description, [2]=Var Value
				//If the variable name matches the parameter sent
				if($varName == $configLineData[0]){
					$validVar = TRUE;
					//If $returnNum != null
					if($returnNum) {
						//echo "<HR>($returnNum): '$configLineData[1]' = '$configLineData[$returnNum]'<HR>";
						return trim($configLineData[$returnNum]); //Return the selected info from array
					} else {
						return $configLineData; //Return array
					}
				}
			}
		}
		if(!$validVar) { displaySiteError("Warning","Invalid variable name ($varName)."); }
	}
	
	/************************************************
	 * Name: Set Configuration Value (setConfigVal) *
	 * Desc: Sets the value of a configuration		*
	 *		 variable based on a variable name.		*
	 * Pre:  String $varName is not null			*
	 *		 String $newVal is not null				*
	 * Post: Returns TRUE if success, FALSE if not	*
	 ************************************************/
	function setConfigVal($varName,$newVal) {
		//Path to configuration file
		global $dashConfigPath;
		$configPath = $dashConfigPath;
		$configLines = file($configPath); //Create array of lines of config file
		
		//Return FALSE if no config file exists... yikes!
		if(!$configLines) { return FALSE; }
		
		//Just in case
		$configFile = "";
		
		//For each line of array, store line to $configLine, index of $configLine_num
		foreach ($configLines as $configLine_num => $configLine) {
			//If the line is not php, a comment (#), and line is not blank ("")
			if((substr($configLine,0,5) != "<?php") && (substr($configLine,0,1) != "#") && (substr($configLine,0,1) != "")) {
				$configLineData = explode("=",$configLine); //Create array of [0]=varName, [1]=Var Description, [2]=Var Value
				$configLineData[2] = trim($configLineData[2]); //Remove end line char
				//If the variable name matches the parameter sent
				if($varName == $configLineData[0]){
					$validVar = TRUE;
					//Encrypt password if password
					if($configLineData[0] == "dashAdminPass") {
						$configArray = explode("=",$configLine);
						$configFile .= "\r\n" . $configArray[0] . "=" . $configArray[1] . "=" . md5(stripslashes($newVal)) . "\r\n";
					} else {
						$configArray = explode("=",$configLine);
						$configFile .= $configArray[0] . "=" . $configArray[1] . "=" . stripslashes($newVal) . "\r\n";
					}
				} else {
					$configFile .= $configLine;
				}
			} else {
				$configFile .= $configLine;
			}
		}
		
		//If the variable was a valid one
		if($validVar) {
			$filename = $_SERVER['DOCUMENT_ROOT'] . "/data/config.ini.php";
			
			//Rewrite the config file
			if (file_exists($dashConfigPath)) {
				if (is_writable($filename)) {
					if (!$handle = fopen($filename, 'w+')) {
						displaySiteError("Fatal","Cannot open the configuration file!","die");
						exit;
					}
					if (fwrite($handle, $configFile) === FALSE) {
						displaySiteError("Fatal","Cannot write to the configuration file!","die");
						exit;
					}
					//Close config file
					fclose($handle);
					//Return TRUE
					return TRUE;
				} else {
					displaySiteError("Fatal","Cannot write to the configuration file!","die");
				}
			} else {
				displaySiteError("Fatal","Configuration file does not exist!","die");
			}
		} else {
			displaySiteError("Warning","Invalid variable name ($varName).");
			return FALSE;
		}
	}

	/************************************************
	 * Name: Display Error (displaySiteError)		*
	 * Desc: Displays an error's details.			*
	 * Pre:  $errorType is a valid error typeint ,	*
	 *		 $errorDetails is a valid error			*
	 *		 description String, $errorReaction is	*
	 *		 NULL or a valid error reaction String,	*
	 *		 and $dieHTML is NULL or a valid 		*
	 *		 String. 								*
	 * Post: Displays the error details and 		*
	 *		 performs the error reation.			*
	 ************************************************/
	function displaySiteError($errorType, $errorDetails, $errorReaction, $dieHTML) {
		//Lets use styles shall we?
		//if(($errorReaction == "die") && ($_SERVER['SCRIPT_NAME'] != "/install/install.php")) { echo "<body style='margin: 0px; padding: 0px;'><link href=\"http://".$_SERVER['HTTP_HOST']."/css/styles.css\" rel=\"stylesheet\" type=\"text/css\" media=\"screen\" /><div style=\"margin: 0px; text-align: left; background: url('gr/header-back.jpg') top left repeat-x; width: 100%; height: 70px; padding: 0px; margin-bottom: 20px;\"><img src=\"gr/header-img.jpg\" alt=\"Project-Alumni\" /></div><div style=\"margin-left: 20px; margin-right: 20px;\">"; }
		
		//What type of error are we?
		if($errorType == "Warning") {
			$errorTitle = "Warning!";
		} else {
			$errorTitle = $errorType . " Error!";
		}
		
		//Are we on the install page? Add some for into then!
		if($_SERVER['SCRIPT_NAME'] == "/install/install.php") {
			$errorDetails = "<span style='font-weight: bold'>The following errors must be rectified before continuing!</span><br />Please go back and try again!<br /><br />" . $errorDetails . "<br /><br /><div style='text-align: center; margin: auto; width: 100%;'><input type=\"button\" value=\"&laquo; Back\" onClick=\"history.back()\" /></div>";
		} else if($errorReaction == "die") {
			$errorDetails = "<span style='font-weight: bold'>The following errors must be rectified before continuing!</span><br />Please go back and try again!  If this error continues, please contact technical support.<br /><br />" . $errorDetails . "<br /><br /><div style='text-align: center; margin: auto; width: 100%;'><input type=\"button\" value=\"&laquo; Back\" onClick=\"history.back()\" /></div>";
		}
		
		//Display error box
		echo "<div class='error-$errorType'><h3>$errorTitle</h3><p>$errorDetails</p></div>";
		
		//Whats our reaction here?
		if(($errorReaction == "die") || ($errorReaction == "die-nohead")) { //DIE!!!
			dieNice($dieHTML);
		}
	}
	
	/************************************************
	 * Name: Kill the page! In a nice way (dieNice) *
	 * Desc: Kills the page after displaying the	*
	 *		 footer... simple I know.				*
	 * Pre:  $extraHTML is a valid string or NULL	*
	 * Post: Displays footer, dies.					*
	 ************************************************/
	function dieNice($extraHTML) {
		if($extraHTML) { echo $extraHTML; }
		if($_SERVER['SCRIPT_NAME'] == "/install/install.php") { displaySiteFooter("short"); } else { displaySiteFooter(); } //Lets be nice and show the footer first
		echo "\n\t</body>\n</html>";
		die();
	}

	/************************************************
	 * Name: Check PHP Version (checkPHPVersion)	*
	 * Desc: Checks for a minimum PHP version.		*
	 * Pre:  $requiredversion is a valid 3-part		*
	 *		 String containing version number.		*
	 * Post: Returns true if meets requirements,	*
	 *		 false if current version is too low.	*
	 ************************************************/
	function checkPHPVersion($requiredversion) {
		$currentversion = PHP_VERSION;
		list($majorC, $minorC, $editC) = split('[/.-]', $currentversion);
		list($majorR, $minorR, $editR) = split('[/.-]', $requiredversion);
		
		if ($majorC > $majorR) return true;
		if ($majorC < $majorR) return false;
		
		// same major - check minor
		if ($minorC > $minorR) return true;
		if ($minorC < $minorR) return false;
		
		// and same minor
		if ($editC  >= $editR)  return true;
		return false;
	}
	
	/************************************************
	 * Name: Check SQL Version (checkSQLVersion)	*
	 * Desc: Checks for a minimum SQL version.		*
	 * Pre:  $requiredversion is a valid 3-part		*
	 *		 String containing version number.		*
	 * Post: Returns true if meets requirements,	*
	 *		 false if current version is too low.	*
	 ************************************************/
	function checkSQLVersion($requiredversion)
	{
		$sqlResult = dbQuery("SELECT VERSION() AS version");
		$row = mysql_fetch_row($sqlResult);
		list($majorC, $minorC, $editC) = split('[/.-]', $row[0]);
		list($majorR, $minorR, $editR) = split('[/.-]', $requiredversion);
		
		if ($majorC > $majorR) return true;
		if ($majorC < $majorR) return false;
		
		// same major - check minor
		if ($minorC > $minorR) return true;
		if ($minorC < $minorR) return false;
		
		// and same minor
		if ($editC  >= $editR)  return true;
		return false;
	}
	
	/************************************************
	 * Name: Check Ban Status (checkBanStatus)		*
	 * Desc: Checks to see if the user is banned.	*
	 * Pre:  NULL									*
	 * Post: Dies if user is banned.				*
	 ************************************************/
	function checkBanStatus() {
		$result = dbQuery( "SELECT `userName` FROM `".getConfigVal("sqlTablePrefix",2)."_blacklist`");
		while($row  =  mysql_fetch_row($result))  { 
			for($i=0;  $i < mysql_num_fields($result);  $i++)  { 
				$user = $row[$i];
				if($user == $_SESSION['userName']){
					$accountBanned = "Yes";
					$result2 = dbQuery( "SELECT `reasonBanned` FROM `".getConfigVal("sqlTablePrefix",2)."_blacklist` WHERE `userName` = '$user'");
					$banReasons = mysql_fetch_row($result2);
					$banReasons = $banReasons[0];
					
					$result2 = dbQuery( "SELECT `banExpires` FROM `".getConfigVal("sqlTablePrefix",2)."_blacklist` WHERE `userName` = '$user'");
					$banExipres = mysql_fetch_row($result2);
					$banExipres = $banExipres[0];
				}
			}            
		}
		
		$result = dbQuery( "SELECT `ipAddress` FROM `".getConfigVal("sqlTablePrefix",2)."_blacklist`");
		$accountBanned = "";
		while($row  =  mysql_fetch_row($result))  { 
			for($i=0;  $i < mysql_num_fields($result);  $i++)  { 
				$ip = $row[$i];
				$userIPAddress = GetHostByName($REMOTE_ADDR);
				if($ip == $userIPAddress){
					$accountBanned = "Yes";
					$result2 = dbQuery( "SELECT `reasonBanned` FROM `".getConfigVal("sqlTablePrefix",2)."_blacklist` WHERE `ipAddress` = '$ip'");
					$banReasons = mysql_fetch_row($result2);
					$banReasons = $banReasons[0];
					
					$result2 = dbQuery( "SELECT `banExpires` FROM `".getConfigVal("sqlTablePrefix",2)."_blacklist` WHERE `ipAddress` = '$ip'");
					$banExipres = mysql_fetch_row($result2);
					$banExipres = $banExipres[0];
				}
			}            
		}
		
		if($accountBanned == "Yes") {				
			echo "\n\t\t\t<h1>".getConfigVal("schoolNameShort",2)." Alumni</h1>\n\t\t\t<h2>Account Banned! </h2>\n\t\t\t<p>Error: For the reason(s) listed below, your account or IP address has been banned from our system.  If you would like to appeal this ban, please <a href='".getConfigVal("alumniWebsite",2)."/index.php?act=contact'>contact the webmaster</a>.</p>\n\t\t\t<p class=\"activationError\"><span class=\"bold\">Ban Reasons:</span><br /><br />Test: $banReasons</p>";
			dieNice("\n\t\t</div>\n\t\t");
		}
	}
	
	/************************************************
	 * Name: Check the sites status (siteStatus)	*
	 * Desc: Checks the online status of the site.	*
	 * Pre:  NULL									*
	 * Post: If site status is offline, the offline *
	 *		 message is shown and the site dies.	*
	 ************************************************/
	function siteStatus() {
		$result = dbQuery( "SELECT * FROM `".getConfigVal("sqlTablePrefix",2)."_site_status` WHERE `ID` = '1'");
		$row  =  mysql_fetch_assoc($result);
		global $siteStatus, $offlineMessage;
		$siteStatus = $row['status'];
		$offlineMessage = trim($row['message']);
		
		if($siteStatus == "Offline"){
			//Show offline message if user is not an administrator
			if($_SESSION['userType'] <> "admin"){
				echo "\n\t\t\t<h1>".getConfigVal("schoolNameShort",2)." Alumni</h1>\n\t\t\t<h2>Alumni Page Offline </h2>\n\t\t\t<p>Due to technical difficulties, the alumni website is temporarily offline.  Please check back later to see if the site is back online.</p>";
				if($offlineMessage <> ""){
					echo "\n\t\t\t<p class=\"activationError\"><span class=\"bold\">Offline Message:</span><br /><br />", $offlineMessage,"</p>";
				}
				dieNice();
			}
		}
	}
?>